==> owncloud-4.0.4.tgz: owncloud/settings/l10n/mk.php <==
<?php $TRANSLATIONS = array(
"OpenID Changed" => "OpenID сменето",
"Invalid request" => "неправилно барање",
"Language changed" => "Јазикот е сменет",
"__language_name__" => "__language_name__",
"Log" => "Записник",
"More" => "Повеќе",
"Add your App" => "Додадете ја Вашата апликација",
"Select an App" => "Избери аппликација",
"-licensed" => "-licensed",
"by" => "од",
"Documentation" => "Документација",
"Managing Big Files" => "Управување со големи датотеки",
"Ask a question" => "Постави прашање",
"Problems connecting to help database." => "Проблем при поврзување со базата за помош",
"Go there manually." => "Оди таму рачно.",
"Answer" => "Одговор",
"You use" => "Вие користите",
"of the available" => "од достапните",
"Desktop and Mobile Syncing Clients" => "Десктоп и мобилник клиенти за синхронизирање",
"Download" => "Преземање",
"Your password got changed" => "Вашата лозинка беше сменета",
"Unable to change your password" => "Вашата лозинка неможе да се смени",
"Current password" => "Моментална лозинка",
"New password" => "Нова лозинка",
"show" => "прикажи",
"Change password" => "Смени лозинка",
"Email" => "Е-пошта",
"Your email address" => "Вашата адреса за е-пошта",
"Fill in an email address to enable password recovery" => "Пополни ја адресата за е-пошта за да може да ја обновуваш лозинката",
"Language" => "Јазик",
"Help translate" => "Помогни во преводот",
"use this address to connect to your ownCloud in your file manager" => "користете ја оваа адреса во менаџерот за датотеки да се поврзете  со Вашиот ownCloud",
"Name" => "Име",
"Password" => "Лозинка",
"Groups" => "Групи",
"Create" => "Создај",
"Default Quota" => "Предефинирана квота",
"Other" => "Останато",
"Quota" => "Квота",
"Delete" => "Избриши"
);

==> owncloud-4.5.7.tgz: owncloud/settings/l10n/mk.php <==
<?php $TRANSLATIONS = array(
"Email saved" => "Електронската пошта е снимена",
"Invalid email" => "Неисправна електронска пошта",
"OpenID Changed" => "OpenID сменето",
"Invalid request" => "неправилно барање",
"Language changed" => "Јазикот е сменет",
"Disable" => "Оневозможи",
"Enable" => "Овозможи",
"Saving..." => "Снимам...",
"__language_name__" => "__language_name__",
"Log" => "Записник",
"More" => "Повеќе",
"Add your App" => "Додадете ја Вашата апликација",
"Select an App" => "Избери аппликација",
"See application page at apps.owncloud.com" => "Види ја страницата со апликации на apps.owncloud.com",
"Documentation" => "Документација",
"Managing Big Files" => "Управување со големи датотеки",
"Ask a question" => "Постави прашање",
"Problems connecting to help database." => "Проблем при поврзување со базата за помош",
"Go there manually." => "Оди таму рачно.",
"Answer" => "Одговор",
"Desktop and Mobile Syncing Clients" => "Десктоп и мобилник клиенти за синхронизирање",
"Download" => "Преземање",
"Unable to change your password" => "Вашата лозинка неможе да се смени",
"Current password" => "Моментална лозинка",
"New password" => "Нова лозинка",
"show" => "прикажи",
"Change password" => "Смени лозинка",
"Email" => "Е-пошта",
"Your email address" => "Вашата адреса за е-пошта",
"Fill in an email address to enable password recovery" => "Пополни ја адресата за е-пошта за да може да ја обновуваш лозинката",
"Language" => "Јазик",
"Help translate" => "Помогни во преводот",
"use this address to connect to your ownCloud in your file manager" => "користете ја оваа адреса во менаџерот за датотеки да се поврзете  со Вашиот ownCloud",
"Name" => "Име",
"Password" => "Лозинка",
"Groups" => "Групи",
"Create" => "Создај",
"Default Quota" => "Предефинирана квота",
"Other" => "Останато",
"Quota" => "Квота",
"Delete" => "Избриши"
);
